% function out = goldbeterleloupmammalianLD(t,x)
% load parameters_mammalian.mat
%% model variables
%x(1): M_P per mRNAs
%x(2): M_C cry mRNAs
%x(3): M_B bmall mRNAs
%x(4): P_C non-phosphorilated PER in cytosol
%x(5): C_C non-phosphorilated CRY in cytosol
%x(6): P_CP phosphorilated PER in cytosol
%x(7): C_CP phosphorilated CRY in cytosol
%x(8): PC_C non-phosphorilated PER-CRY complex in cytosol
%x(9): PC_N  non-phosphorilated PER-CRY complex in nucleus
%x(10):PC_CP phosphorilated PER-CRY complex in cytosol
%x(11):PC_NP phosphorilated PER-CRY complex in nucleus
%x(12):B_C non-phosphorilated BMAL1 in cytosol
%x(13):B_CP phosphorilated BMAL1 in cytosol
%x(14):B_N non-phosphorilated BMAL1 in nucleus
%x(15):B_NP phosphorilated BMAL1 in nucleus
%x(16): I_N Inactive complex between PER-CRY and CLOCK-BMAL1 in the nucleus


%% Model equations

 function dxdt=goldbeterleloupmammalianLD(t,x,p)

 
        
%         k1=0.4;k2=0.2;k3=0.4;k4=0.2;k5=0.4;k6=0.2;k7=0.5;k8=0.1;
%         KAP=0.7;KAC=0.6;KIB=2.2;kdmb=0.01;kdmc=0.01;kdmp=0.01;kdnc=0.12;
%         kdn=0.01;Kd=0.3;Kdp=0.1;Kp=0.1;KmB=0.4;KmC=0.4;KmP=0.31;kstot=1.0;
%         ksB=0.12;ksC=1.6;ksP=0.6;n=4;m=2;Vphos=0.4;V1B=0.5;V1C=0.6;
%         V1P=0.4;V1PC=0.4;V2B=0.1;V2C=0.1;V2P=0.3;V2PC=0.1;V3B=0.5;
%         V3PC=0.4;V4B=0.2;V4PC=0.1;vdBC=0.5;vdBN=0.6;vdCC=0.7;vdIN=0.8;
%         vdPC=0.7;vdPCC=0.7;vdPCN=0.7;vmB=0.8;vmC=1.0;vmP=1.1;vsTot=1.0;
%         vsB=1.0;vsC=1.1;vsP=1.5;

         k1=p(1);k2=p(2);k3=p(3);k4=p(4);k5=p(5);k6=p(6);k7=p(7);k8=p(8);
         KAP=p(9);KAC=p(10);KIB=p(11);kdmb=p(12);kdmc=p(13);kdmp=p(14);kdnc=p(15);
         kdn=p(16);Kd=p(17);Kdp=p(18);Kp=p(19);KmB=p(20);KmC=p(21);KmP=p(22);kstot=1.0;
         ksB=p(23);ksC=p(24);ksP=p(25);n=4;m=2;Vphos=p(26);V1B=p(27);V1C=p(28);
         V1P=p(29);V1PC=p(30);V2B=p(31);V2C=p(32);V2P=p(33);V2PC=p(34);V3B=p(35);
         V3PC=p(36);V4B=p(37);V4PC=p(38);vdBC=p(39);vdBN=p(40);vdCC=p(41);vdIN=p(42);
         vdPC=p(43);vdPCC=p(44);vdPCN=p(45);vmB=p(46);vmC=p(47);vmP=p(48);vsTot=1.0;
         vsB=p(49);vsC=p(50);vsP1=p(51);vsP2=p(52);

        
        dxdt=zeros(16,1);
        
        
        
        
        
        
        
        dxdt(1)=vsPprofile(t,p) * x(14)^n / ( KAP^n + x(14)^n )-vmP * x(1) / ( KmP + x(1) )-kdmp * x(1);
        dxdt(2)=vsC * x(14)^n / ( KAC^n + x(14)^n )-vmC * x(2) / ( KmC + x(2) )-kdmc * x(2);
        dxdt(3)=vsB * KIB^m / ( KIB^m + x(14)^m )-vmB * x(3) / ( KmB + x(3) )-kdmb*x(3);%?
        
        dxdt(4)=ksP*x(1)-V1P * x(4) / ( Kp + x(4) ) + V2P * x(6) / ( Kdp + x(6) )+k4*x(8)-k3*x(4)*x(5)-kdn*x(4);
        dxdt(5)=ksC*x(2)-V1C * x(5) / ( Kp + x(5) ) + V2C * x(7) / ( Kdp + x(7) )+k4*x(8)-k3*x(4)*x(5)-kdnc*x(5);
        dxdt(6)=V1P * x(4) / ( Kp + x(4) )-V2P * x(6) / ( Kdp + x(6) )-vdPC * x(6) / ( Kd + x(6) )-kdn*x(6);
        dxdt(7)=V1C * x(5) / ( Kp + x(5) )-V2C * x(7) / ( Kdp + x(7) )-vdCC * x(7) / ( Kd + x(7) )-kdn*x(7);
        
        dxdt(8)=-V1PC * x(8) / ( Kp + x(8) )+V2PC * x(10) / ( Kdp + x(10) )-k4*x(8)+k3*x(4)*x(5)+k2*x(9)-k1*x(8)-kdn*x(8);
        dxdt(9)=-V3PC * x(9) / ( Kp + x(9) )+V4PC * x(11) / ( Kdp + x(11) )-k2*x(9)+k1*x(8)-k7*x(14)*x(9)+k8*x(16)-kdn*x(9);
        dxdt(10)=V1PC * x(8) / ( Kp + x(8) )-V2PC * x(10) / ( Kdp + x(10) )-vdPCC * x(10) / ( Kd + x(10) )-kdn*x(10);
        dxdt(11)=V3PC * x(9) / ( Kp + x(9) )-V4PC * x(11) / ( Kdp + x(11) )-vdPCN * x(11) / ( Kd + x(11) )-kdn*x(11);
        
        dxdt(12)=ksB*x(3)-V1B * x(12) / ( Kp + x(12) ) + V2B * x(13) / ( Kdp + x(13) )-k5*x(12)+k6*x(14)-kdn*x(12);
        dxdt(13)=V1B * x(12) / ( Kp + x(12) )-V2B * x(13) / ( Kdp + x(13) )-vdBC * x(13) / ( Kd + x(13) )-kdn*x(13);
        dxdt(14)=-V3B * x(14) / ( Kp + x(14) )+V4B * x(15) / ( Kdp + x(15) )+k5*x(12)-k6*x(14)-k7*x(14)*x(9)+k8*x(16)-kdn*x(14);
        dxdt(15)= V3B * x(14) / ( Kp + x(14) )-V4B * x(15) / ( Kdp + x(15) )-vdBN * x(15) / ( Kd + x(15) )-kdn*x(15);
       
        dxdt(16)= -k8*x(16)+k7*x(14)*x(9)-vdIN * x(16) / ( Kd + x(16) )-kdn*x(16);
    


end

