% function out = goldbeterleloupmammalianLD(t,x)
% load parameters_mammalian.mat
%% model variables
%x(1): M_P per mRNAs
%x(2): M_C cry mRNAs
%x(3): M_B bmall mRNAs
%x(4): P_C non-phosphorilated PER in cytosol
%x(5): C_C non-phosphorilated CRY in cytosol
%x(6): P_CP phosphorilated PER in cytosol
%x(7): C_CP phosphorilated CRY in cytosol
%x(8): PC_C non-phosphorilated PER-CRY complex in cytosol
%x(9): PC_N  non-phosphorilated PER-CRY complex in nucleus
%x(10):PC_CP phosphorilated PER-CRY complex in cytosol
%x(11):PC_NP phosphorilated PER-CRY complex in nucleus
%x(12):B_C non-phosphorilated BMAL1 in cytosol
%x(13):B_CP phosphorilated BMAL1 in cytosol
%x(14):B_N non-phosphorilated BMAL1 in nucleus
%x(15):B_NP phosphorilated BMAL1 in nucleus
%x(16): I_N Inactive complex between PER-CRY and CLOCK-BMAL1 in the nucleus


%% Model equations

 function dydt=mammalian_LD(t,y)

 
        
        k1=0.4;k2=0.2;k3=0.4;k4=0.2;k5=0.4;k6=0.2;k7=0.5;k8=0.1;
        KAP=0.7;KAC=0.6;KIB=2.2;kdmb=0.01;kdmc=0.01;kdmp=0.01;kdnc=0.12;
        kdn=0.01;Kd=0.3;Kdp=0.1;Kp=0.1;KmB=0.4;KmC=0.4;KmP=0.31;kstot=1.0;
        ksB=0.12;ksC=1.6;ksP=0.6;n=4;m=2;Vphos=0.4;V1B=0.5;V1C=0.6;
        V1P=0.4;V1PC=0.4;V2B=0.1;V2C=0.1;V2P=0.3;V2PC=0.1;V3B=0.5;
        V3PC=0.4;V4B=0.2;V4PC=0.1;vdBC=0.5;vdBN=0.6;vdCC=0.7;vdIN=0.8;
        vdPC=0.7;vdPCC=0.7;vdPCN=0.7;vmB=0.8;vmC=1.0;vmP=1.1;vsTot=1.0;
        vsB=1.0;vsC=1.1;vsP=1.5;
        
        dydt=zeros(16,1);
        
        
        
        
        
        
        
        dydt(1)=vsP_profile(t) * y(14)^n / ( KAP^n + y(14)^n )-vmP * y(1) / ( KmP + y(1) )-kdmp * y(1);
        dydt(2)=vsC * y(14)^n / ( KAC^n + y(14)^n )-vmC * y(2) / ( KmC + y(2) )-kdmc * y(2);
        dydt(3)=vsB * KIB^m / ( KIB^m + y(14)^m )-vmB * y(3) / ( KmB + y(3) )-kdmb*y(3);
        
        dydt(4)=ksP*y(1)-V1P * y(4) / ( Kp + y(4) ) + V2P * y(6) / ( Kdp + y(6) )+k4*y(8)-k3*y(4)*y(5)-kdn*y(4);
        dydt(5)=ksC*y(2)-V1C * y(5) / ( Kp + y(5) ) + V2C * y(7) / ( Kdp + y(7) )+k4*y(8)-k3*y(4)*y(5)-kdnc*y(5);
        dydt(6)=V1P * y(4) / ( Kp + y(4) )-V2P * y(6) / ( Kdp + y(6) )-vdPC * y(6) / ( Kd + y(6) )-kdn*y(6);
        dydt(7)=V1C * y(5) / ( Kp + y(5) )-V2C * y(7) / ( Kdp + y(7) )-vdCC * y(7) / ( Kd + y(7) )-kdn*y(7);
        
        dydt(8)=-V1PC * y(8) / ( Kp + y(8) )+V2PC * y(10) / ( Kdp + y(10) )-k4*y(8)+k3*y(4)*y(5)+k2*y(9)-k1*y(8)-kdn*y(8);
        dydt(9)=-V3PC * y(9) / ( Kp + y(9) )+V4PC * y(11) / ( Kdp + y(11) )-k2*y(9)+k1*y(8)-k7*y(14)*y(9)+k8*y(16)-kdn*y(9);
        dydt(10)=V1PC * y(8) / ( Kp + y(8) )-V2PC * y(10) / ( Kdp + y(10) )-vdPCC * y(10) / ( Kd + y(10) )-kdn*y(10);
        dydt(11)=V3PC * y(9) / ( Kp + y(9) )-V4PC * y(11) / ( Kdp + y(11) )-vdPCN * y(11) / ( Kd + y(11) )-kdn*y(11);
        
        dydt(12)=ksB*y(3)-V1B * y(12) / ( Kp + y(12) ) + V2B * y(13) / ( Kdp + y(13) )-k5*y(12)+k6*y(14)-kdn*y(12);
        dydt(13)=V1B * y(12) / ( Kp + y(12) )-V2B * y(13) / ( Kdp + y(13) )-vdBC * y(13) / ( Kd + y(13) )-kdn*y(13);
        dydt(14)=-V3B * y(14) / ( Kp + y(14) )+V4B * y(15) / ( Kdp + y(15) )+k5*y(12)-k6*y(14)-k7*y(14)*y(9)+k8*y(16)-kdn*y(14);
        dydt(15)= V3B * y(14) / ( Kp + y(14) )-V4B * y(15) / ( Kdp + y(15) )-vdBN * y(15) / ( Kd + y(15) )-kdn*y(15);
       
        dydt(16)= -k8*y(16)+k7*y(14)*y(9)-vdIN * y(16) / ( Kd + y(16) )-kdn*y(16);
    


end

