
%% initialize model variables & time interval for simulation
%x(1): M_P per mRNAs
%x(2): M_C cry mRNAs
%x(3): M_B bmall mRNAs
%x(4): P_C non-phosphorilated PER in cytosol
%x(5): C_C non-phosphorilated CRY in cytosol
%x(6): P_CP phosphorilated PER in cytosol
%x(7): C_CP phosphorilated CRY in cytosol
%x(8): PC_C non-phosphorilated PER-CRY complex in cytosol
%x(9): PC_N  non-phosphorilated PER-CRY complex in nucleus
%x(10):PC_CP phosphorilated PER-CRY complex in cytosol
%x(11):PC_NP phosphorilated PER-CRY complex in nucleus
%x(12):B_C non-phosphorilated BMAL1 in cytosol
%x(13):B_CP phosphorilated BMAL1 in cytosol
%x(14):B_N non-phosphorilated BMAL1 in nucleus
%x(15):B_NP phosphorilated BMAL1 in nucleus
%x(16): I_N Inactive complex between PER-CRY and CLOCK-BMAL1 in the nucleus

%Model only in the dark
%y0=[1.6; 1.4; 9; 0; 0; 0; 0; 0; 1; 0; 0; 2; 0; 1.9; 0; 0];
%precise dark model
%y0=[1.84249677556018;1.44449384364633;8.93415312443163;0.765534536024320;2.60315378454424;0.110070650940103;0.592035248417500;0.362479266526353;0.0334240293501080;0.124644752227401;0.0271486377160258;2.23552123416278;0.906014069480978;1.58872593149637;0.309778926864657;0.00702065233611978];

%Model in light-dark
y0=[2.5; 1.7; 9.5; 0; 0; 0; 0; 0; 1.0; 0; 0; 2; 0; 1.9; 0; 0];
%precise values



%% initialize time window for simulations
tspan = 0:0.1:24;



%% run simulation for total with the set of initial conditions y0

[T, Y] =  ode45(@(t,y) mammalian_LD(t,y),tspan,y0);

MP = Y(:,1); 

MC = Y(:,2);

MB = Y(:,3);

PTot = Y(:,4)+Y(:,6)+Y(:,8)+Y(:,9)+Y(:,10)+Y(:,11)+Y(:,16); %equation for total PER concentration

CTot = Y(:,5)+Y(:,7)+Y(:,8)+Y(:,9)+Y(:,10)+Y(:,11)+Y(:,16); %equation for total CRY concentration

BTot= Y(:,12)+Y(:,13)+Y(:,14)+Y(:,15)+Y(:,16); %equation for total BSMAL1




%% plot simulation results for P_t,T_t, & phase plane
figure;
%plot simulation results with set 1
%subplot(2,1,1);
plot(T,MP,T,MC,T,MB,T,PTot, T,CTot,T,BTot);
%plot(T,X(:,1),T,X(:,2), T,X(:,3),T,X(:,4),T,X(:,5),T,X(:,6),T,X(:,7),T,X(:,8),T,X(:,9),T,X(:,10));
xlabel('Time (h)');ylabel('Concentrations (nM)');
legend('MP','MC','MB','Total PER Protein','Total CRY Protein','Total Bmall Protein');
axis([0,24,0,25])
%subplot(2,1,2);
%plot(T,X(:,5));
%xlabel('Time (h)');ylabel('Concentrations (\muM)');
%legend('M_T');






