% function out = goldbeterleloupmammalianLD(t,x)
% load parameters_mammalian.mat
%% model variables
%x(1): M_P per mRNAs
%x(2): M_C cry mRNAs
%x(3): M_B bmall mRNAs
%x(4): P_C non-phosphorilated PER in cytosol
%x(5): C_C non-phosphorilated CRY in cytosol
%x(6): P_CP phosphorilated PER in cytosol
%x(7): C_CP phosphorilated CRY in cytosol
%x(8): PC_C non-phosphorilated PER-CRY complex in cytosol
%x(9): PC_N  non-phosphorilated PER-CRY complex in nucleus
%x(10):PC_CP phosphorilated PER-CRY complex in cytosol
%x(11):PC_NP phosphorilated PER-CRY complex in nucleus
%x(12):B_C non-phosphorilated BMAL1 in cytosol
%x(13):B_CP phosphorilated BMAL1 in cytosol
%x(14):B_N non-phosphorilated BMAL1 in nucleus
%x(15):B_NP phosphorilated BMAL1 in nucleus
%x(16): I_N Inactive complex between PER-CRY and CLOCK-BMAL1 in the nucleus


%% Model equations

 function dydt=sub_mammalian_LD(t,y)

 
        
        k1=0.4;k2=0.2;k3=0.4;k4=0.2;k5=0.4;k6=0.2;k7=0.5;k8=0.1;
        KAP=0.7;KAC=0.6;KIB=2.2;kdmb=0.01;kdmc=0.01;kdmp=0.01;kdnc=0.12;
        kdn=0.01;Kd=0.3;Kdp=0.1;Kp=0.1;KmB=0.4;KmC=0.4;KmP=0.31;kstot=1.0;
        ksB=0.12;ksC=1.6;ksP=0.6;n=4;m=2;Vphos=0.4;V1B=0.5;V1C=0.6;
        V1P=0.4;V1PC=0.4;V2B=0.1;V2C=0.1;V2P=0.3;V2PC=0.1;V3B=0.5;
        V3PC=0.4;V4B=0.2;V4PC=0.1;vdBC=0.5;vdBN=0.6;vdCC=0.7;vdIN=0.8;
        vdPC=0.7;vdPCC=0.7;vdPCN=0.7;vmB=0.8;vmC=1.0;vmP=1.1;vsTot=1.0;
        vsB=1.0;vsC=1.1;vsP=1.5;
        
        dydt=zeros(16,1);
        
        %SUB-MODELS.
        %From 0 to the average time 9. I take as the initial values the ones in 0
          I=[1,1,0,1,1,0,1,1,0,1,1,0,0,1,0,1,1,0,0,1,0,1,1,1,0,1,0,1,0,1,0,0,1,0,1,0,1,0,0,1,1,0,0,1,0,1,0,1,1,1,0,1,1,0,1,1,0,1,0,1,0,1,0,1,1,0,0,0,1,1,1,0,0,1,1,0];
        
        % From average 9 to average 60: at 9 we suppose that happens instantly
        % all the activation between 3 a 15. We take as values of activity
        % the ones from 15
        % I=[1 1 0 1 1 0 1 1 0 1 0 0 0 1 0 1 0 0 0 1 0 1 1 1 0 1 0 1 0 0 0 1 1 0 1 0 1 0 0 1 1 0 0 1 0 1 0 1 0 1 0 1 1 0 1 1 0 1 0 1 0 1 0 1 1 1 0 0 1 1 1 0 0 1 1 0];
        % From average 60 to average 125: at 60 we suppose that happens instantly
        % all the activation between 38 a 86. We take as values of activity
        % the ones from 86.
        % I=[0 1 0 0 1 0 1 1 0 1 0 0 1 1 0 1 0 0 1 1 0 1 1 1 0 1 0 1 0 0 0 1 1 1 1 0 0 0 1 1 1 0 0 1 0 1 0 1 0 1 0 1 1 0 1 0 0 1 0 1 0 1 0 1 0 1 0 0 1 1 1 0 0 1 1 0];
        % From average 125 to average 200: at 125 we suppose that happens instantly
        % all the activation between 98 and 156. We take as values of activity
        % the ones from 156.
        % I=[1 1 0 1 1 0 1 1 0 0 1 1 1 1 0 0 1 0 1 1 0 1 1 1 0 1 1 1 0 1 0 1 0 1 1 0 1 0 1 1 1 0 0 1 0 1 0 1 0 1 0 1 1 0 1 0 0 1 0 1 0 1 0 1 0 1 0 0 1 1 1 0 0 1 1 0];
        % From average 200 to average 240: at 200 we suppose that happens instantly
        % all the activation between 173 and 229. We take as values of activity
        % the ones from 229.
        % I=[1 1 0 1 1 0 1 1 0 1 1 0 0 1 0 1 1 0 0 1 0 1 1 1 0 1 0 1 0 1 0 0 1 0 1 0 1 0 0 1 1 0 0 1 0 1 0 1 1 1 0 1 1 0 1 1 0 1 0 1 0 1 0 1 1 0 0 0 1 1 1 0 0 1 1 0];
        
        dydt(1)=I(1)*vsP_profile(t) * y(14)^n / ( KAP^n + y(14)^n )-I(2)*vmP * y(1) / ( KmP + y(1) )-I(3)*kdmp * y(1);
        dydt(2)=I(4)*vsC * y(14)^n / ( KAC^n + y(14)^n )-I(5)*vmC * y(2) / ( KmC + y(2) )-I(6)*kdmc * y(2);
        dydt(3)=I(7)*vsB * KIB^m / ( KIB^m + y(14)^m )-I(8)*vmB * y(3) / ( KmB + y(3) )-I(9)*kdmb*y(3);%?
        
        dydt(4)=I(10)*ksP*y(1)-I(11)*V1P * y(4) / ( Kp + y(4) ) + I(12)*V2P * y(6) / ( Kdp + y(6) )+I(13)*k4*y(8)-I(14)*k3*y(4)*y(5)-I(15)*kdn*y(4);
        dydt(5)=I(16)*ksC*y(2)-I(17)*V1C * y(5) / ( Kp + y(5) ) + I(18)*V2C * y(7) / ( Kdp + y(7) )+I(19)*k4*y(8)-I(20)*k3*y(4)*y(5)-I(21)*kdnc*y(5);
        dydt(6)=I(22)*V1P * y(4) / ( Kp + y(4) )-I(23)*V2P * y(6) / ( Kdp + y(6) )-I(24)*vdPC * y(6) / ( Kd + y(6) )-I(25)*kdn*y(6);
        dydt(7)=I(26)*V1C * y(5) / ( Kp + y(5) )-I(27)*V2C * y(7) / ( Kdp + y(7) )-I(28)*vdCC * y(7) / ( Kd + y(7) )-I(29)*kdn*y(7);
        
        dydt(8)=-I(30)*V1PC * y(8) / ( Kp + y(8) )+I(31)*V2PC * y(10) / ( Kdp + y(10) )-I(32)*k4*y(8)+I(33)*k3*y(4)*y(5)+I(34)*k2*y(9)-I(35)*k1*y(8)-I(36)*kdn*y(8);
        dydt(9)=-I(37)*V3PC * y(9) / ( Kp + y(9) )+I(38)*V4PC * y(11) / ( Kdp + y(11) )-I(39)*k2*y(9)+I(40)*k1*y(8)-I(41)*k7*y(14)*y(9)+I(42)*k8*y(16)-I(43)*kdn*y(9);
        dydt(10)=I(44)*V1PC * y(8) / ( Kp + y(8) )-I(45)*V2PC * y(10) / ( Kdp + y(10) )-I(46)*vdPCC * y(10) / ( Kd + y(10) )-I(47)*kdn*y(10);
        dydt(11)=I(48)*V3PC * y(9) / ( Kp + y(9) )-I(49)*V4PC * y(11) / ( Kdp + y(11) )-I(50)*vdPCN * y(11) / ( Kd + y(11) )-I(51)*kdn*y(11);
        
        dydt(12)=I(52)*ksB*y(3)-I(53)*V1B * y(12) / ( Kp + y(12) ) + I(54)*V2B * y(13) / ( Kdp + y(13) )-I(55)*k5*y(12)+I(56)*k6*y(14)-I(57)*kdn*y(12);
        dydt(13)=I(58)*V1B * y(12) / ( Kp + y(12) )-I(59)*V2B * y(13) / ( Kdp + y(13) )-I(60)*vdBC * y(13) / ( Kd + y(13) )-I(61)*kdn*y(13);
        dydt(14)=-I(62)*V3B * y(14) / ( Kp + y(14) )+I(63)*V4B * y(15) / ( Kdp + y(15) )+I(64)*k5*y(12)-I(65)*k6*y(14)-I(66)*k7*y(14)*y(9)+I(67)*k8*y(16)-I(68)*kdn*y(14);
        dydt(15)= I(69)*V3B * y(14) / ( Kp + y(14) )-I(70)*V4B * y(15) / ( Kdp + y(15) )-I(71)*vdBN * y(15) / ( Kd + y(15) )-I(72)*kdn*y(15);
       
        dydt(16)= -I(73)*k8*y(16)+I(74)*k7*y(14)*y(9)-I(75)*vdIN * y(16) / ( Kd + y(16) )-I(76)*kdn*y(16);
    


end

